IvsChatApi class

Amazon IVS Chat control plane (ivschat.<region>.amazonaws.com), SigV4 service ivschat.

WebSocket URL for clients: wss://edge.ivschat.<region>.amazonaws.com (see AWS Chat User Guide).

Constructors

IvsChatApi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createChatToken({required String region, required String accessKeyId, required String secretAccessKey, String? sessionToken, required String roomArn, required String userId, List<String> capabilities = const ['SEND_MESSAGE'], Map<String, String>? attributes, int sessionDurationInMinutes = 120}) Future<Map<String, dynamic>>
Returns map with token, tokenExpirationTime, sessionExpirationTime.
createRoom({required String region, required String accessKeyId, required String secretAccessKey, String? sessionToken, required String name, int maximumMessageLength = 500, int maximumMessageRatePerSecond = 30}) Future<Map<String, dynamic>>
deleteRoom({required String region, required String accessKeyId, required String secretAccessKey, String? sessionToken, required String roomArn}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited