IvsChatLine class

One WebSocket session to Amazon IVS Chat (User Guide).

Constructors

IvsChatLine({required String id, required String senderLabel, required String content, String? sendTime})

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderLabel String
final
sendTime String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited